@@ -2,6 +2,7 @@ from Microsoft.Finance.DataStandards.UnitTest.TestCase.CommonTestCase import Com
 from Microsoft.Finance.DataStandards.UnitTest.TestCase.FactTestCase import FactTestCase
 from Microsoft.Finance.DataStandards.UnitTest.TestSuite.BaseTestSuite import BaseTestSuite
 from pyspark.sql.session import SparkSession
+from unittest import TestLoader
 
 class FactTestSuite(BaseTestSuite):
 
@@ -11,10 +12,15 @@ class FactTestSuite(BaseTestSuite):
         self.__excludeFromAggregations = excludeFromAggregations
 
     def queue_tests(self) -> None:
-        factTestCase = FactTestCase(self.SparkSession, self.TableDataFrame, self.FieldInfo, self.__linkedDimensions, self.DatabaseName, self.TableName, self.TableCount, self.CustomEvents, self.__excludeFromAggregations)
-        commonTestCase = CommonTestCase(self.TableDataFrame, self.FieldInfo, self.CustomEvents)
-        self.TestSuite.addTest(factTestCase)
-        self.TestSuite.addTest(commonTestCase)
 
-    def run_tests(self) -> None:
-        self.TestRunner.run(self.TestSuite)
+        loader = TestLoader()
+
+        names = loader.getTestCaseNames(FactTestCase)
+
+        for name in names:
+            self.TestSuite.addTest(FactTestCase(self.SparkSession, self.TableDataFrame, self.FieldInfo, self.__linkedDimensions, self.DatabaseName, self.TableName, self.TableCount, self.CustomEvents, self.__excludeFromAggregations))
+
+        names = loader.getTestCaseNames(CommonTestCase)
+
+        for name in names:
+            self.TestSuite.addTest(CommonTestCase(self.TableDataFrame, self.FieldInfo, self.CustomEvents))
